function PARA = get_parallel_variables(PARA)
index = labindex;
EBHag = PARA.IS.EBHag; 
EBHbg = PARA.IS.EBHbg; 
EBT = PARA.IS.EBT; 
Ballast = PARA.IS.Ballast;
LSW = PARA.IS.LSW; 
RSW = PARA.IS.RSW;
switch numlabs
    case 1
        disp('single mode - 1 tundra tile');
        PARA.ensemble.TileType = {'tundra'};
        PARA.ensemble.TileWidth = 100;
    case 9
        disp('1 railway tile, 2 filling tile, 2 filling outer tile, 2 shoulder tile, 2 tundra tile');
        PARA.ensemble.TileType = {'tundra','left shoulder','left filling outer','left filling',...
                                  'railway','right filling','right filling outer','right shoulder','tundra'};
        PARA.ensemble.TileWidth = PARA.IS.TileWidth;
end
PARA.IS.NumberTiles_Railway = sum((string(PARA.ensemble.TileType) == 'railway'));
PARA.IS.NumberTiles_Filling = sum((string(PARA.ensemble.TileType) == 'left filling')) + sum((string(PARA.ensemble.TileType) == 'right filling'));
PARA.IS.NumberTiles_Filling_Outer = sum((string(PARA.ensemble.TileType) == 'left filling outer')) + sum((string(PARA.ensemble.TileType) == 'right filling outer'));
PARA.IS.NumberTiles_Shoulder = sum((string(PARA.ensemble.TileType) == 'left shoulder')) + sum((string(PARA.ensemble.TileType) == 'right shoulder'));
PARA.IS.NumberTiles_IS = PARA.IS.NumberTiles_Railway + PARA.IS.NumberTiles_Filling + PARA.IS.NumberTiles_Filling_Outer + PARA.IS.NumberTiles_Shoulder;
PARA.IS.NumberTiles_Toe = sum((string(PARA.ensemble.TileType) == 'toe'));
PARA.IS.NumberTiles_Tundra = sum((string(PARA.ensemble.TileType) == 'tundra'));

rel_maxSnow = PARA.snow.relative_maxSnow;
TileDistance = 0.5 * (PARA.ensemble.TileWidth(1 : length(PARA.ensemble.TileWidth) - 1) + PARA.ensemble.TileWidth(2 : length(PARA.ensemble.TileWidth))); % distance between the mid-point of adjacent tiles
if numlabs == 1
    DistanceRC = cumsum(PARA.ensemble.TileWidth) - 0.5 * PARA.ensemble.TileWidth; % distance of tile mid-point to railway center
else
    for i = 1:length(PARA.ensemble.TileWidth)
        if i <= find(string(PARA.ensemble.TileType) == 'railway')
            DistanceRC(:,i) = sum(PARA.ensemble.TileWidth(i:find(string(PARA.ensemble.TileType)=='railway'))) - PARA.ensemble.TileWidth(find(string(PARA.ensemble.TileType)=='railway'))/2 - PARA.ensemble.TileWidth(i)/2;
        else
            DistanceRC(:,i) = sum(PARA.ensemble.TileWidth(find(string(PARA.ensemble.TileType)=='railway'):i)) - PARA.ensemble.TileWidth(find(string(PARA.ensemble.TileType)=='railway'))/2- PARA.ensemble.TileWidth(i)/2;
        end
    end
end

WidthRailway = sum(PARA.ensemble.TileWidth(string(PARA.ensemble.TileType) == 'railway'));
WidthLeftFilling = sum(PARA.ensemble.TileWidth(string(PARA.ensemble.TileType) == 'left filling'));
WidthRightFilling = sum(PARA.ensemble.TileWidth(string(PARA.ensemble.TileType) == 'right filling'));
WidthLeftFillingOuter = sum(PARA.ensemble.TileWidth(string(PARA.ensemble.TileType) == 'left filling outer'));
WidthRightFillingOuter = sum(PARA.ensemble.TileWidth(string(PARA.ensemble.TileType) == 'right filling outer'));
SlopeEB = PARA.IS.SlopeEB;

for n = 1 : numlabs
    switch string(PARA.ensemble.TileType(n))
        case 'railway'
            PARA.ensemble.initial_altitude(n) = EBHag + Ballast;
            PARA.ensemble.snow.relative_maxSnow(n) = 0;
            PARA.ensemble.soil.albedo(n) = 0.28;
            PARA.ensemble.soil.externalWaterFlux(n) = 0.;
            PARA.ensemble.soil.ratioET(n) = 0.;
            PARA.ensemble.rootDepth = 0;
        case 'left filling'
            PARA.ensemble.initial_altitude(n) = EBHag;
            PARA.ensemble.snow.relative_maxSnow(n) = rel_maxSnow;
            PARA.ensemble.soil.albedo(n) = 0.257;
            PARA.ensemble.soil.externalWaterFlux(n) = 0.;
            PARA.ensemble.soil.ratioET(n) = 0.;
            PARA.ensemble.rootDepth = 0;
        case 'right filling'
            PARA.ensemble.initial_altitude(n) = EBHag;
            PARA.ensemble.snow.relative_maxSnow(n) = rel_maxSnow;
            PARA.ensemble.soil.albedo(n) = 0.257;
            PARA.ensemble.soil.externalWaterFlux(n) = 0.;
            PARA.ensemble.soil.ratioET(n) = 0.;
            PARA.ensemble.rootDepth = 0;
        case 'left filling outer'
            PARA.ensemble.initial_altitude(n) = EBHag;
            PARA.ensemble.snow.relative_maxSnow(n) = rel_maxSnow;
            PARA.ensemble.soil.albedo(n) = 0.28;
            PARA.ensemble.soil.externalWaterFlux(n) = 0.;
            PARA.ensemble.soil.ratioET(n) = 0.;
            PARA.ensemble.rootDepth = 0;
        case 'right filling outer'
            PARA.ensemble.initial_altitude(n) = EBHag;
            PARA.ensemble.snow.relative_maxSnow(n) = rel_maxSnow;
            PARA.ensemble.soil.albedo(n) = 0.28;
            PARA.ensemble.soil.externalWaterFlux(n) = 0.;
            PARA.ensemble.soil.ratioET(n) = 0.;
            PARA.ensemble.rootDepth = 0;
        case 'left shoulder'
            PARA.ensemble.initial_altitude(n) = EBHag - SlopeEB .* (DistanceRC(n) - WidthRailway/2 - WidthLeftFilling - WidthLeftFillingOuter);
            PARA.ensemble.snow.relative_maxSnow(n) = rel_maxSnow;
            PARA.ensemble.soil.albedo(n) = 0.28;
            PARA.ensemble.soil.externalWaterFlux(n) = 0.;
            PARA.ensemble.soil.ratioET(n) = 0.;
            PARA.ensemble.rootDepth = 0;
        case 'right shoulder'
            PARA.ensemble.initial_altitude(n) = EBHag - SlopeEB .* (DistanceRC(n) - WidthRailway/2 - WidthRightFilling - WidthRightFillingOuter);
            PARA.ensemble.snow.relative_maxSnow(n) = rel_maxSnow;
            PARA.ensemble.soil.albedo(n) = 0.28;
            PARA.ensemble.soil.externalWaterFlux(n) = 0.;
            PARA.ensemble.soil.ratioET(n) = 0.;
            PARA.ensemble.rootDepth = 0;
        case 'toe'
            PARA.ensemble.initial_altitude(n) = 0;
            PARA.ensemble.snow.relative_maxSnow(n) = rel_maxSnow;
            PARA.ensemble.soil.albedo(n) = 0.21;
            PARA.ensemble.soil.externalWaterFlux(n) = 0.;
            PARA.ensemble.soil.ratioET(n) = 0.5;
            PARA.ensemble.rootDepth = 0.1;
        case 'tundra'
            PARA.ensemble.initial_altitude(n) = 0;
            PARA.ensemble.snow.relative_maxSnow(n) = rel_maxSnow;
            PARA.ensemble.soil.albedo(n) = 0.237;
            PARA.ensemble.soil.externalWaterFlux(n) = 0.;
            PARA.ensemble.soil.ratioET(n) = 0.5;
            PARA.ensemble.rootDepth = 0.1;
    end
end

PARA.IS.TileType = PARA.ensemble.TileType(index);
PARA.snow.relative_maxSnow = PARA.ensemble.snow.relative_maxSnow(index);
PARA.soil.albedo = PARA.ensemble.soil.albedo(index);
PARA.soil.externalWaterFlux = PARA.ensemble.soil.externalWaterFlux(index);
PARA.soil.ratioET = PARA.ensemble.soil.ratioET(index);

A = diag(ones(numlabs - 1, 1), -1) + diag(ones(numlabs - 1, 1),1);
PARA.ensemble.distanceBetweenPoints = zeros(numlabs, numlabs);
for i = 1 : numlabs
    for j = 1 : numlabs
        if (i - j) == -1
            PARA.ensemble.distanceBetweenPoints(i,j) = TileDistance(i) * A(i,j);
        elseif (i - j) == 1
            PARA.ensemble.distanceBetweenPoints(i,j) = TileDistance(i - 1) * A(i,j);
        end
    end
end
PARA.ensemble.weight = PARA.ensemble.TileWidth;
PARA.ensemble.altitude = PARA.ensemble.initial_altitude;
PARA.ensemble.surface_altitude = PARA.ensemble.initial_altitude;
PARA.ensemble.soil_altitude = PARA.ensemble.initial_altitude;

contact_length = 1000.;
PARA.ensemble.thermal_contact_length = contact_length * A;
PARA.ensemble.thermalDistance = PARA.ensemble.distanceBetweenPoints;

PARA.ensemble.area = contact_length * PARA.ensemble.TileWidth;
PARA.ensemble.water_fluxes = zeros(numlabs, numlabs);
PARA.ensemble.hydraulic_conductivity = PARA.soil.hydraulic_conductivity * A;

PARA.ensemble.water_table_altitude = nan(1, numlabs);
PARA.ensemble.hydraulic_contact_length = PARA.ensemble.thermal_contact_length;
PARA.ensemble.infiltration_altitude = nan(1, numlabs);
PARA.ensemble.hydraulicDistance = PARA.ensemble.distanceBetweenPoints;

for i = 1 : numlabs
    boundaryCondition{i} = 'NoBC';
end
boundaryCondition = transpose(boundaryCondition);
Darcy_elevation = nan(1, numlabs);
Darcy_fluxFactor = nan(1, numlabs);
if (PARA.soil.drainage == 1)
    boundaryCondition{end} = 'DarcyReservoir';
    Darcy_elevation(end) = 20;
    Darcy_fluxFactor(end) = PARA.soil.hydraulic_conductivity;
end
PARA.ensemble.boundaryCondition(length(boundaryCondition)).type = boundaryCondition(end);
[PARA.ensemble.boundaryCondition.type] = boundaryCondition{:};
for i = 1 : numlabs
    if strcmp(boundaryCondition{i},'DarcyReservoir') == 1
        PARA.ensemble.boundaryCondition(i).parameters.elevation = Darcy_elevation(i);
        PARA.ensemble.boundaryCondition(i).parameters.fluxFactor = Darcy_fluxFactor(i);
    end
end

PARA.ensemble.terrain_index_snow = calculateTerrainIndexSnow(PARA.ensemble.altitude, round(PARA.ensemble.weight));
PARA.ensemble.immobile_snow_heigth = 0.1 * ones(1, numlabs);
PARA.ensemble.snow_scaling = ones(1, numlabs);

PARA.location.area = PARA.ensemble.area(index);
PARA.location.initial_altitude = PARA.ensemble.initial_altitude(index);
PARA.location.altitude = PARA.ensemble.altitude(index);
PARA.location.surface_altitude = PARA.ensemble.surface_altitude(index);
PARA.location.water_table_altitude = PARA.ensemble.water_table_altitude(index);
PARA.location.infiltration_altitude = PARA.ensemble.infiltration_altitude(index);
PARA.location.soil_altitude = PARA.ensemble.soil_altitude(index);
PARA.location.absolute_maxWater_altitude = PARA.ensemble.altitude(end) + PARA.soil.relative_maxWater;

%% Soil stratigraphy
BR =6.0;
zXice = PARA.Exp.DepthXice; % depth xice layer
dXice = PARA.Exp.ThicknessXice; % thickness xice layer
switch string(PARA.IS.TileType)
    case 'railway'
        PARA.soil.layer_properties = ...
             [0.0               0.00         0.70          0.0         6        0.30 ; ...
             Ballast            0.10         0.75          0.0         5        0.25 ; ...
          EBT+Ballast           0.15         0.70          0.0         1        0.30 ; ...
       EBHag + Ballast + 2.0    0.30         0.60          0.0         2        0.40 ; ...
       EBHag + Ballast + BR     0.15         0.70          0.0         1        0.30 ];              
        check_layer_properties(PARA)
    case 'left filling'
        PARA.soil.layer_properties = ...
            [0.0               0.10         0.75          0.0         5        0.25 ; ...
             EBT               0.15         0.70          0.0         1        0.30 ; ...
          EBHag + 2.0          0.30         0.60          0.0         2        0.40 ; ...
          EBHag + BR           0.15         0.70          0.0         1        0.30 ];
        check_layer_properties(PARA)
    case 'right filling'
        PARA.soil.layer_properties = ...
            [0.0               0.10         0.75          0.0         5        0.25 ; ...
             EBT               0.15         0.70          0.0         1        0.30 ; ...
          EBHag + 2.0          0.30         0.60          0.0         2        0.40 ; ...
          EBHag + BR           0.15         0.70          0.0         1        0.30 ];
        check_layer_properties(PARA)
    case 'left filling outer'
        PARA.soil.layer_properties = ...
            [0.0               0.00         0.70          0.0         6       0.30; ...
        LSW/2 *SlopeEB         0.10         0.75          0.0         5       0.25 ; ...
            EBT                0.15         0.70          0.0         1       0.30 ; ...
          EBHag + 2.0          0.30         0.60          0.0         2       0.40 ; ...
          EBHag + BR           0.15         0.70          0.0         1       0.30 ];
        check_layer_properties(PARA)
    case 'right filling outer'
        PARA.soil.layer_properties = ...
            [0.0               0.00         0.70          0.0         6       0.30; ...
        RSW/2 *SlopeEB         0.10         0.75          0.0         5       0.25 ; ...
            EBT                0.15         0.70          0.0         1       0.30 ; ...
          EBHag + 2.0          0.30         0.60          0.0         2       0.40 ; ...
          EBHag + BR           0.15         0.70          0.0         1       0.30 ];
        check_layer_properties(PARA)
    case 'left shoulder'
        EBHag_s = PARA.ensemble.initial_altitude(index);
        EBT_s = PARA.ensemble.initial_altitude(index) + EBHbg;
        PARA.soil.layer_properties = ...
            [0.0                 0.00      0.70           0.0         6        0.30 ; ...
             LSW * SlopeEB       0.10      0.75           0.0         5        0.25 ; ...
             EBT_s               0.15      0.70           0.0         1        0.30 ; ...
             EBHag_s + 2.0       0.30      0.60           0.0         2        0.40 ; ...
             EBHag_s + BR        0.15      0.70           0.0         1        0.30 ];
         check_layer_properties(PARA)
    case 'right shoulder'
        EBHag_s = PARA.ensemble.initial_altitude(index);
        EBT_s = PARA.ensemble.initial_altitude(index) + EBHbg;
        PARA.soil.layer_properties = ...
            [0.0                 0.00      0.70           0.0         6        0.30 ; ...
             RSW * SlopeEB       0.10      0.75           0.0         5        0.25 ; ...
             EBT_s               0.15      0.70           0.0         1        0.30 ; ...
             EBHag_s + 2.0       0.30      0.60           0.0         2        0.40 ; ...
             EBHag_s + BR        0.15      0.70           0.0         1        0.30 ];
         check_layer_properties(PARA)
    case 'tundra'
        PARA.soil.layer_properties = ...
            [0.0                0.15      0.75           0.00         1        0.25 ;...
             2.0                0.30      0.60           0.00         2        0.40 ;...
             BR                 0.15      0.70           0.00         1        0.30 ];
         check_layer_properties(PARA)
end
if (PARA.modules.xice)
    Xice_ub = [zXice             0.60     0.40     0.0     1     0.40];
    Xice_lb = [zXice + dXice     0.30     0.60     0.0     2     0.40];
    switch string(PARA.IS.TileType)
        case 'tundra'
            PARA.soil.layer_properties = [PARA.soil.layer_properties(1,:); Xice_ub; Xice_lb; PARA.soil.layer_properties(3:end,:)];
        case 'left shoulder'
            Xice_ub(1) = Xice_ub(1) + EBHag_s; Xice_lb(1) = Xice_lb(1) + EBHag_s;
            PARA.soil.layer_properties = [PARA.soil.layer_properties(1:3,:); Xice_ub; Xice_lb; PARA.soil.layer_properties(5:end,:)];
        case 'right shoulder'
            Xice_ub(1) = Xice_ub(1) + EBHag_s; Xice_lb(1) = Xice_lb(1) + EBHag_s;
            PARA.soil.layer_properties = [PARA.soil.layer_properties(1:3,:); Xice_ub; Xice_lb; PARA.soil.layer_properties(5:end,:)];
        case {'left filling','right filling'}
            Xice_ub(1) = Xice_ub(1) + EBHag; Xice_lb(1) = Xice_lb(1) + EBHag;
            PARA.soil.layer_properties = [PARA.soil.layer_properties(1:2,:); Xice_ub; Xice_lb; PARA.soil.layer_properties(4:end,:)];
        case 'left filling outer'
            Xice_ub(1) = Xice_ub(1) + EBHag; Xice_lb(1) = Xice_lb(1) + EBHag;
            PARA.soil.layer_properties = [PARA.soil.layer_properties(1:3,:); Xice_ub; Xice_lb; PARA.soil.layer_properties(5:end,:)];
        case 'right filling outer'
            Xice_ub(1) = Xice_ub(1) + EBHag; Xice_lb(1) = Xice_lb(1) + EBHag;
            PARA.soil.layer_properties = [PARA.soil.layer_properties(1:3,:); Xice_ub; Xice_lb; PARA.soil.layer_properties(5:end,:)];
        case 'railway'
            Xice_ub(1) = Xice_ub(1) + EBHag + Ballast; Xice_lb(1) = Xice_lb(1) + EBHag + Ballast;
            PARA.soil.layer_properties = [PARA.soil.layer_properties(1:3,:); Xice_ub; Xice_lb; PARA.soil.layer_properties(5:end,:)];
    end
    check_layer_properties(PARA)
end
end